Documentation
¶
Index ¶
Constants ¶
const XDG_CONFIG_DIRS = "XDG_CONFIG_DIRS"
const XDG_CONFIG_HOME = "XDG_CONFIG_HOME"
Variables ¶
This section is empty.
Functions ¶
func Load ¶
Read one or more TOML configuration files and merge their contents. Merge overlays existing configuration settings and adds non-existing ones. The operation reads instances of the configuration file in an order opposite to the XDG Base Directory Specification to process the most "important" or higher preference directories last, thereby, ensuring their configuration values dominate the the resultant config file. This mechanism is analogous to static inhertance.
Notes
- This function generates a typed error: "LoadFail", when it's unable to locate a single instance of the desired configuration file.
Types ¶
type Duration ¶
TOML golang decoder requires extension to enable support of formatted golang duration strings.
func (*Duration) UnmarshalText ¶
Click to show internal directories.
Click to hide internal directories.